@@ -7,6 +7,7 @@ from slai_cli.create.local_config_helper import LocalConfigHelper
 from slai_cli.profile.configure import get_credentials
 from slai.modules.runtime import detect_credentials, detect_runtime
 from slai.exceptions import NoCredentialsFound
+from os import path
 
 
 def requires_slai_credentials(callback, *outer_args, **outer_kwargs):
@@ -42,11 +43,17 @@ def requires_slai_project(callback):
     def wrapper(*args, **kwargs):
 
         slai_directory_present = Path(".slai").is_dir()
+
         if not slai_directory_present:
             log.warn(
                 "No project detected in this directory, create one with 'slai create <project_name>'."  # noqa
             )
             return
+        elif slai_directory_present and not Path(".slai/config.yml").exists():
+            log.warn(
+                "No project detected in this directory, create one with 'slai create <project_name>'."  # noqa
+            )
+            return
 
         local_config_helper = LocalConfigHelper()
         local_config_helper.check_local_config()
